@@ -55,6 +55,7 @@ __all__ = [
     "ExceptionPrettyPrinter",
     "JSONRenderer",
     "KeyValueRenderer",
+    "LogfmtRenderer",
     "StackInfoRenderer",
     "TimeStamper",
     "UnicodeDecoder",
@@ -524,7 +525,8 @@ def _make_stamper(
     else:
 
         def now() -> datetime.datetime:
-            # A naive local datetime is fine here, because we only format it.
+            # We don't need the TZ for our own formatting. We add it only for
+            # user-defined formats later.
             return datetime.datetime.now()  # noqa: DTZ005
 
     if fmt is None:
@@ -551,12 +553,18 @@ def _make_stamper(
 
         return stamper_iso_local
 
-    def stamper_fmt(event_dict: EventDict) -> EventDict:
-        event_dict[key] = now().strftime(fmt)
-
+    def stamper_fmt_local(event_dict: EventDict) -> EventDict:
+        event_dict[key] = now().astimezone().strftime(fmt)
         return event_dict
 
-    return stamper_fmt
+    def stamper_fmt_utc(event_dict: EventDict) -> EventDict:
+        event_dict[key] = now().strftime(fmt)
+        return event_dict
+
+    if utc:
+        return stamper_fmt_utc
+
+    return stamper_fmt_local
 
 
 class MaybeTimeStamper:
