@@ -5,7 +5,9 @@
 
 import pytest
 
-from structlog import get_config, get_logger, reset_defaults, testing
+import structlog
+
+from structlog import get_config, get_logger, testing
 from structlog.testing import (
     CapturedCall,
     CapturingLogger,
@@ -17,10 +19,6 @@ from structlog.testing import (
 
 
 class TestCaptureLogs:
-    @classmethod
-    def teardown_class(cls):
-        reset_defaults()
-
     def test_captures_logs(self):
         """
         Log entries are captured and retain their structure.
@@ -64,9 +62,8 @@ class TestCaptureLogs:
         """
         orig_procs = self.get_active_procs()
 
-        with pytest.raises(NotImplementedError):
-            with testing.capture_logs():
-                raise NotImplementedError("from test")
+        with pytest.raises(NotImplementedError), testing.capture_logs():
+            raise NotImplementedError("from test")
 
         assert orig_procs is self.get_active_procs()
 
@@ -90,6 +87,35 @@ class TestCaptureLogs:
             }
         ]
 
+    def test_captures_log_level_mapping(self):
+        """
+        exceptions and warn log levels are mapped like in regular loggers.
+        """
+        structlog.configure(
+            processors=[
+                structlog.stdlib.ProcessorFormatter.wrap_for_formatter,
+            ],
+            logger_factory=structlog.stdlib.LoggerFactory(),
+            wrapper_class=structlog.stdlib.BoundLogger,
+        )
+        with testing.capture_logs() as logs:
+            get_logger().exception("hello", answer=42)
+            get_logger().warn("again", answer=23)
+
+        assert [
+            {
+                "event": "hello",
+                "answer": 42,
+                "exc_info": True,
+                "log_level": "error",
+            },
+            {
+                "answer": 23,
+                "event": "again",
+                "log_level": "warning",
+            },
+        ] == logs
+
 
 class TestReturnLogger:
     # @pytest.mark.parametrize("method", stdlib_log_methods)
